@@ -28,28 +28,39 @@
 
 static DevPrivateKeyRec fbScreenPrivateKeyRec;
 DevPrivateKey
-fbGetScreenPrivateKey(void) { return &fbScreenPrivateKeyRec; }
+fbGetScreenPrivateKey(void)
+{
+    return &fbScreenPrivateKeyRec;
+}
 
 static DevPrivateKeyRec fbGCPrivateKeyRec;
 DevPrivateKey
-fbGetGCPrivateKey (void) { return &fbGCPrivateKeyRec; }
+fbGetGCPrivateKey(void)
+{
+    return &fbGCPrivateKeyRec;
+}
 
 static DevPrivateKeyRec fbWinPrivateKeyRec;
 DevPrivateKey
-fbGetWinPrivateKey (void) { return &fbWinPrivateKeyRec; }
+fbGetWinPrivateKey(void)
+{
+    return &fbWinPrivateKeyRec;
+}
 
 Bool
 fbAllocatePrivates(ScreenPtr pScreen, DevPrivateKey *pGCKey)
 {
     if (pGCKey)
-	*pGCKey = &fbGCPrivateKeyRec;
-    
-    if (!dixRegisterPrivateKey(&fbGCPrivateKeyRec, PRIVATE_GC, sizeof(FbGCPrivRec)))
-	return FALSE;
-    if (!dixRegisterPrivateKey(&fbScreenPrivateKeyRec, PRIVATE_SCREEN, sizeof (FbScreenPrivRec)))
-	return FALSE;
+        *pGCKey = &fbGCPrivateKeyRec;
+
+    if (!dixRegisterPrivateKey
+        (&fbGCPrivateKeyRec, PRIVATE_GC, sizeof(FbGCPrivRec)))
+        return FALSE;
+    if (!dixRegisterPrivateKey
+        (&fbScreenPrivateKeyRec, PRIVATE_SCREEN, sizeof(FbScreenPrivRec)))
+        return FALSE;
     if (!dixRegisterPrivateKey(&fbWinPrivateKeyRec, PRIVATE_WINDOW, 0))
-	return FALSE;
+        return FALSE;
 
     return TRUE;
 }
